#' @name  data25j3
#' @title data25j3
#' Data with 300 observations for \eqn{p = 0.25} with 3 outcomes
#'
#' @details
#'
#' Generates 300 observations for the simulation study at the \eqn{25^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (2, 2, 1)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.25}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 3 categories using the
#' cut-points (0, 4).
#'
#' @docType data
#'
#' @usage data(data25j3)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11), 1565–1578.
#'
#'
#' @keywords datasets
#'
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL

#' @name  data50j3
#' @title data50j3
#' Data with 300 observations for \eqn{p = 0.5} with 3 outcomes
#'
#' @details
#' Generates 300 observations for the simulation study at the \eqn{50^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (2, 2, 1)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.50}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 3 categories using the
#' cut-points (0, 4).
#'
#' @docType data
#' @usage data(data50j3)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11): 1565–1578.
#'
#'
#' @keywords datasets
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL

#' @name  data75j3
#' @title data75j3
#' Data with 300 observations for \eqn{p = 0.75} with 3 outcomes
#'
#' @details
#' Generates 300 observations for the simulation study at the \eqn{75^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (2, 2, 1)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.75}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 3 categories using the
#' cut-points (0, 4).
#'
#' @docType data
#' @usage data(data75j3)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11): 1565–1578.
#'
#' @keywords datasets
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL

#' @name  data25j4
#' @title data25j4
#' Data with 300 observations for \eqn{p = 0.25} with 4 outcomes
#'
#' @details
#'
#' Generates 300 observations for the simulation study at the \eqn{25^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (-2, 3, 4)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.25}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 4 categories using the
#' cut-points (0, 2, 3).
#'
#' @docType data
#' @usage data(data25j4)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11): 1565–1578.
#'
#'
#' @keywords datasets
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL

#' @name  data50j4
#' @title data50j4
#' Data with 300 observations for \eqn{p = 0.5} with 4 outcomes
#'
#' @details
#' Generates 300 observations for the simulation study at the \eqn{50^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (-2, 3, 4)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.50}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 4 categories using the
#' cut-points (0, 2, 3).
#'
#'
#' @docType data
#' @usage data(data50j4)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11): 1565–1578.
#'
#'
#' @keywords datasets
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL

#' @name  data75j4
#' @title data75j4
#' Data with 300 observations for \eqn{p = 0.75} with 4 outcomes
#'
#' @details
#' Generates 300 observations for the simulation study at the \eqn{75^{th}}
#' quantile. The specifications are
#' \eqn{\beta = (-2, 3, 4)}, \eqn{X} ~ \eqn{MVN(0_{2}, \Sigma)} where
#' \eqn{\Sigma = [1, 0.25; 0.25, 1]}, and \eqn{\epsilon} ~ AL(\eqn{0, \sigma = 1, p = 0.75}).
#'
#' The errors are generated from an asymmetric Laplace distribution
#' by using its normal–exponential mixture formulation.
#'
#' The continuous value are classified into 4 categories using the
#' cut-points (0, 2, 3).
#'
#' @docType data
#' @usage data(data75j4)
#'
#' @return Returns a list with components
#' \itemize{
#' \item{\code{x}: }{a matrix of covariates.}
#' \item{\code{y}: }{a matrix of ordinal outcomes.}
#' }
#'
#' @references Kozumi, H. and Kobayashi, G. (2011). “Gibbs Sampling Methods for Bayesian Quantile Regression.”
#'  Journal of Statistical Computation and Simulation, 81(11): 1565–1578.
#'
#'
#' @keywords datasets
#' @seealso \link[MASS]{mvrnorm}, Asymmetric Laplace Distribution
#'
NULL
